Struct diem_management::storage::StorageWrapper[][src]

pub struct StorageWrapper { /* fields omitted */ }
A helper to handle common error handling and functionality for tooling

Implementations

Retrieves the Public key, that is stored as a public key

Retrieves the Public key that is stored as a public key

Retrieves public key from the stored private key

Retrieves the previous public key from the stored private key

Retrieves public key from the stored private key

Retrieves public key from the stored private key

Sign a transaction

Sign a transaction with the given version